@@ -7,7 +7,7 @@ using namespace Rcpp;
 // min(which(!x))-1
 // returns 0 if all(x) is TRUE
 // [[Rcpp::export]]
-int C_find_first_false(LogicalVector x){
+int C_find_first_false(const LogicalVector x){
   int i = 0;
   while(x(i)){
     i++;
@@ -21,7 +21,7 @@ int C_find_first_false(LogicalVector x){
 
 // selects the rows with only one FALSE and determines the columns with only TRUE value in these rows
 // [[Rcpp::export]]
-LogicalVector C_redund(LogicalMatrix x){
+LogicalVector C_redund(const LogicalMatrix x){
   int k = x.ncol();
   LogicalVector possibly_redundant = rep(true, k);
   for (int i=0; i < x.nrow(); i++){
@@ -38,15 +38,15 @@ LogicalVector C_redund(LogicalMatrix x){
 // Applies C_redund repeatedly
 // l specifies the grouping of the columns in x - thus sum(l) must equal ncol(x)
 // [[Rcpp::export]]
-List C_mredund(LogicalMatrix x, IntegerVector l){
+List C_mredund(const LogicalMatrix x, const IntegerVector l){
   if (sum(l) != x.ncol()) stop("sum(l) must equal ncol(x)");
   int start, end=-1;
   List out(l.size());
   for (int i=0; i<l.size(); i++){
     start = end+1;
     end += l[i]; 
-    //Rcout << start << " " << end << std::endl;
-    out[i] = C_redund(x(_, Range(start, end)));
+    LogicalMatrix subx = clone(x)(_, Range(start, end));
+    out[i] = C_redund(subx);
   }
   return out;
 }
